# ChargeType


## Enum

* `ONETIME` (value: `'OneTime'`)

* `RECURRING` (value: `'Recurring'`)

* `USAGE` (value: `'Usage'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


